# MR22142UNO

LIBRERIA para resolver sistemas de ecuaciones lineales y no lineales mediante:

Metodos:
- Eliminacion de Gauss
- Gauss-Jordan
- Regla de Cramer
- Descomposicion LU
- Jacobi 
- Gauss-Seidel
- Biseccion

## Instalacion

Desde PyPI:

```bash
pip install MR22142UNO
